package galatea.dialog;
public class Tstamp
{ 
	public static final String TSTAMP = 
		"Galatea Dialog Studio 2.2.2.2 (080817)";
	
	public static final String COPYRIGHT = 
		"(c)2003-2008 Takuya NISHIMOTO (nishimoto@m.ieice.org)";
	
	public static float STATEMAP_PDOC_VERSION = 0.901f;

	/*
	 * history:
	 * Ver 1.0.0   (030822) : IPA Final Release (2003-08)
	 * Ver 1.0.1   (050720) : ISTC CD-ROM (2006-03)
	 * Ver 1.1.0   (061020) : ISTC CD-ROM (2006-10)
	 * 
	 * Ver 2.0.3.2 (060207) : ISTC CD-ROM (2006-03)
	 * Ver 2.1.0   (061020) : ISTC CD-ROM (2006-10)
	 * Ver 2.1.1   (070114) : ISTC CD-ROM (2007-03 & 2007-07)
	 * Ver 2.1.1.1 (070803) : ISTC demo in Kyoto
	 * Ver 2.1.1.2 (070809) : fix grammar filename & submit post (pdoc 0.901)
	 * Ver 2.1.1.3 (070824) : fix "open local file" default location
	 * Ver 2.1.1.4 (070907) : uses javax.script
	 * Ver 2.1.1.5 (071217) : option "UseMozillaRhino"
	 * Ver 2.1.1.6 (080203) : disable javax.script, use CookieManager (Java6)
	 * Ver 2.1.1.7 (080210) : DM._setup() change
	 * Ver 2.1.1.8 (080213) : window tab "Http" / generic type cleanup
	 * Ver 2.1.1.9 (080214) : more window tabs / scripting fix
	 * Ver 2.1.2.0 (080214) : bug fix on Linux
	 * Ver 2.1.2.1 (080214) : includes (again) js.jar
	 * Ver 2.2.1   (080216) : UseMozillaRhino=1
	 * Ver 2.2.1.2 (080409) : Use mkdfa.exe as default, create c:/tmp if not exist
	 * Ver 2.2.2   (080501) : mkdfa.pl as default again, SubProcess fix, sort config 
	 * Ver 2.2.2.1 (080815) : _fromSRMtell() hack for julius-4.0.2  
	 * Ver 2.2.2.2 (080817) : NetUtil loadXMLFile / sleep at _gotoRunLevel2  
	 */
}

